@@ -2,9 +2,11 @@
 //!
 //! Define basic characteristics of a bundle, like its name, type, and version.
 //!
-//! The Information Property List file associated with a bundle tells you how to interpret the bundle’s contents.
-//! The file describes fundamental features, like whether the bundle contains an app, a framework, or something else.
-//! It also includes identifying characteristics of the bundle, like an identifier, a human-readable name, and a version.
+//! The Information Property List file associated with a bundle tells you how to interpret
+//! the bundle’s contents. The file describes fundamental features, like whether the
+//! bundle contains an app, a framework, or something else. It also includes identifying
+//! characteristics of the bundle, like an identifier, a human-readable name, and a
+//! version.
 //!
 //! ## Framework
 //! * Bundle Resources
@@ -12,7 +14,7 @@
 use crate::{serialize_enum_option, serialize_vec_enum_option};
 use serde::{Deserialize, Serialize};
 
-/// Categorization.
+/// Categorization
 #[derive(Deserialize, Serialize, Debug, Clone, PartialEq, Default)]
 pub struct Categorization {
     /// The type of bundle.
@@ -31,7 +33,7 @@ pub struct Categorization {
     /// ## Framework
     /// Core Foundation
     #[serde(
-        rename(serialize = "CFBundlePackageType"),
+        rename = "CFBundlePackageType",
         skip_serializing_if = "Option::is_none"
     )]
     pub bundle_package_type: Option<String>,
@@ -43,22 +45,22 @@ pub struct Categorization {
     /// ## Framework
     /// Core Services
     #[serde(
-        rename(serialize = "LSApplicationCategoryType"),
+        rename = "LSApplicationCategoryType",
         skip_serializing_if = "Option::is_none",
         serialize_with = "serialize_enum_option"
     )]
     pub application_category_type: Option<AppCategoryType>,
 }
 
-/// Identification.
+/// Identification
 #[derive(Deserialize, Serialize, Debug, Clone, PartialEq, Default)]
 pub struct Identification {
     /// A unique identifier for a bundle.
     ///
     /// A bundle ID uniquely identifies a single app throughout the system.
-    /// The bundle ID string must contain only alphanumeric characters (A-Z, a-z, and 0-9),
-    /// hyphens (-), and periods (.). The string should be in reverse-DNS format.
-    /// Bundle IDs are case sensitive.
+    /// The bundle ID string must contain only alphanumeric characters (A-Z, a-z, and
+    /// 0-9), hyphens (-), and periods (.). The string should be in reverse-DNS
+    /// format. Bundle IDs are case sensitive.
     ///
     /// ## Availability
     /// * iOS 2.0+
@@ -68,7 +70,7 @@ pub struct Identification {
     ///
     /// ## Framework
     /// Core Foundation
-    #[serde(rename(serialize = "CFBundleIdentifier"))]
+    #[serde(rename = "CFBundleIdentifier")]
     pub bundle_identifier: String,
     /// The bundle ID of the watchOS app.
     ///
@@ -81,7 +83,7 @@ pub struct Identification {
     /// ## Framework
     /// * WatchKit
     #[serde(
-        rename(serialize = "WKAppBundleIdentifier"),
+        rename = "WKAppBundleIdentifier",
         skip_serializing_if = "Option::is_none"
     )]
     pub app_bundle_identifier: Option<String>,
@@ -97,13 +99,13 @@ pub struct Identification {
     /// ## Framework
     /// * WatchKit
     #[serde(
-        rename(serialize = "WKCompanionAppBundleIdentifier"),
+        rename = "WKCompanionAppBundleIdentifier",
         skip_serializing_if = "Option::is_none"
     )]
     pub companion_app_bundle_identifier: Option<String>,
 }
 
-/// Naming.
+/// Naming
 #[derive(Deserialize, Serialize, Debug, Clone, PartialEq, Default)]
 pub struct Naming {
     /// A user-visible short name for the bundle.
@@ -119,9 +121,10 @@ pub struct Naming {
     ///
     /// ## Framework
     /// Core Foundation
-    #[serde(rename(serialize = "CFBundleName"))]
+    #[serde(rename = "CFBundleName")]
     pub bundle_name: Option<String>,
-    /// The user-visible name for the bundle, used by Siri and visible on the iOS Home screen.
+    /// The user-visible name for the bundle, used by Siri and visible on the iOS Home
+    /// screen.
     ///
     /// Use this key if you want a product name that's longer than CFBundleName.
     ///
@@ -134,7 +137,7 @@ pub struct Naming {
     /// ## Framework
     /// Core Foundation
     #[serde(
-        rename(serialize = "CFBundleDisplayName"),
+        rename = "CFBundleDisplayName",
         skip_serializing_if = "Option::is_none"
     )]
     pub bundle_display_name: Option<String>,
@@ -148,22 +151,21 @@ pub struct Naming {
     ///
     /// ## Framework
     /// Core Foundation
-    #[serde(
-        rename(serialize = "CFBundleSpokenName"),
-        skip_serializing_if = "Option::is_none"
-    )]
+    #[serde(rename = "CFBundleSpokenName", skip_serializing_if = "Option::is_none")]
     pub bundle_spoken_name: Option<String>,
 }
 
-/// Bundle Version.
+/// Bundle Version
 #[derive(Deserialize, Serialize, Debug, Clone, PartialEq, Default)]
 pub struct BundleVersion {
     /// The version of the build that identifies an iteration of the bundle.
     ///
-    /// This key is a machine-readable string composed of one to three period-separated integers,
-    /// such as 10.14.1. The string can only contain numeric characters (0-9) and periods.
+    /// This key is a machine-readable string composed of one to three period-separated
+    /// integers, such as 10.14.1. The string can only contain numeric characters
+    /// (0-9) and periods.
     ///
-    /// Each integer provides information about the build version in the format \[Major\].\[Minor\].\[Patch\]:
+    /// Each integer provides information about the build version in the format
+    /// \[Major\].\[Minor\].\[Patch\]:
     /// - Major: A major revision number.
     /// - Minor: A minor revision number.
     /// - Patch: A maintenance release number.
@@ -172,8 +174,9 @@ pub struct BundleVersion {
     /// You can also abbreviate the build version by using only one or two integers,
     /// where missing integers in the format are interpreted as zeros.
     /// For example, 0 specifies 0.0.0, 10 specifies 10.0.0, and 10.5 specifies 10.5.0.
-    /// This key is required by the App Store and is used throughout the system to identify the version of the build.
-    /// For macOS apps, increment the build version before you distribute a build.
+    /// This key is required by the App Store and is used throughout the system to
+    /// identify the version of the build. For macOS apps, increment the build version
+    /// before you distribute a build.
     ///
     /// ## Availability
     /// * iOS 2.0+
@@ -183,17 +186,16 @@ pub struct BundleVersion {
     ///
     /// ## Framework
     /// Core Foundation
-    #[serde(
-        rename(serialize = "CFBundleVersion"),
-        skip_serializing_if = "Option::is_none"
-    )]
+    #[serde(rename = "CFBundleVersion", skip_serializing_if = "Option::is_none")]
     pub bundle_version: Option<String>,
     /// The release or version number of the bundle.
     ///
-    /// This key is a user-visible string for the version of the bundle. The required format is three period-separated integers,
-    /// such as 10.14.1. The string can only contain numeric characters (0-9) and periods.
+    /// This key is a user-visible string for the version of the bundle. The required
+    /// format is three period-separated integers, such as 10.14.1. The string can
+    /// only contain numeric characters (0-9) and periods.
     ///
-    /// Each integer provides information about the release in the format \[Major\].\[Minor\].\[Patch\]:
+    /// Each integer provides information about the release in the format
+    /// \[Major\].\[Minor\].\[Patch\]:
     /// - Major: A major revision number.
     /// - Minor: A minor revision number.
     /// - Patch: A maintenance release number.
@@ -209,7 +211,7 @@ pub struct BundleVersion {
     /// ## Framework
     /// Core Foundation
     #[serde(
-        rename(serialize = "CFBundleShortVersionString"),
+        rename = "CFBundleShortVersionString",
         skip_serializing_if = "Option::is_none"
     )]
     pub bundle_short_version_string: Option<String>,
@@ -226,7 +228,7 @@ pub struct BundleVersion {
     /// ## Framework
     /// Core Foundation
     #[serde(
-        rename(serialize = "CFBundleInfoDictionaryVersion"),
+        rename = "CFBundleInfoDictionaryVersion",
         skip_serializing_if = "Option::is_none"
     )]
     pub bundle_info_dictionary_version: Option<String>,
@@ -238,13 +240,13 @@ pub struct BundleVersion {
     /// ## Framework
     /// * Foundation
     #[serde(
-        rename(serialize = "NSHumanReadableCopyright"),
+        rename = "NSHumanReadableCopyright",
         skip_serializing_if = "Option::is_none"
     )]
     pub human_readable_copyright: Option<String>,
 }
 
-/// Operating System Version.
+/// Operating System Version
 #[derive(Deserialize, Serialize, Debug, Clone, PartialEq, Default)]
 pub struct OperatingSystemVersion {
     /// The minimum operating system version required for the app to run.
@@ -258,11 +260,12 @@ pub struct OperatingSystemVersion {
     /// ## Framework
     /// * Core Services
     #[serde(
-        rename(serialize = "LSMinimumSystemVersion"),
+        rename = "LSMinimumSystemVersion",
         skip_serializing_if = "Option::is_none"
     )]
     pub minimum_system_version: Option<String>,
-    /// The minimum version of macOS required for the app to run on a set of architectures.
+    /// The minimum version of macOS required for the app to run on a set of
+    /// architectures.
     ///
     /// ## Availability
     /// * macOS 10.0+
@@ -270,11 +273,12 @@ pub struct OperatingSystemVersion {
     /// ## Framework
     /// * Core Services
     #[serde(
-        rename(serialize = "LSMinimumSystemVersionByArchitecture"),
+        rename = "LSMinimumSystemVersionByArchitecture",
         skip_serializing_if = "Option::is_none"
     )]
     pub minimum_system_version_by_architecture: Option<MinimumSystemVersionByArchitecture>,
-    /// The minimum operating system version required for the app to run on iOS, tvOS, and watchOS.
+    /// The minimum operating system version required for the app to run on iOS, tvOS, and
+    /// watchOS.
     ///
     /// The App Store uses this key to indicate the OS releases on which your app can run.
     ///
@@ -285,10 +289,7 @@ pub struct OperatingSystemVersion {
     ///
     /// ## Framework
     /// * Core Services
-    #[serde(
-        rename(serialize = "MinimumOSVersion"),
-        skip_serializing_if = "Option::is_none"
-    )]
+    #[serde(rename = "MinimumOSVersion", skip_serializing_if = "Option::is_none")]
     pub minimum_os_version: Option<String>,
     /// A Boolean value indicating whether the app must run in iOS.
     ///
@@ -297,10 +298,7 @@ pub struct OperatingSystemVersion {
     ///
     /// ## Framework
     /// * Core Services
-    #[serde(
-        rename(serialize = "LSRequiresIPhoneOS"),
-        skip_serializing_if = "Option::is_none"
-    )]
+    #[serde(rename = "LSRequiresIPhoneOS", skip_serializing_if = "Option::is_none")]
     pub requires_iphone_os: Option<bool>,
     /// A Boolean value that indicates whether the bundle is a watchOS app.
     ///
@@ -312,28 +310,27 @@ pub struct OperatingSystemVersion {
     ///
     /// ## Framework
     /// * WatchKit
-    #[serde(
-        rename(serialize = "WKWatchKitApp"),
-        skip_serializing_if = "Option::is_none"
-    )]
+    #[serde(rename = "WKWatchKitApp", skip_serializing_if = "Option::is_none")]
     pub watch_kit_app: Option<bool>,
 }
 
-/// Localization.
+/// Localization
 #[derive(Deserialize, Serialize, Debug, Clone, PartialEq, Default)]
 pub struct Localization {
     /// The default language and region for the bundle, as a language ID.
     ///
-    /// The system uses this key as the language if it can't locate a resource for the user’s preferred language.
-    /// The value should be a language ID that identifies a language, dialect, or script.
+    /// The system uses this key as the language if it can't locate a resource for the
+    /// user’s preferred language. The value should be a language ID that identifies a
+    /// language, dialect, or script.
     ///
-    /// To distinguish between different languages and regional dialects, use a language designator with a region
-    /// designator and a script designator separated by hyphens. To specify the English language as it's used in
-    /// the United Kingdom, use en-GB, where GB is the region designator. To represent Mandarin Chinese,
+    /// To distinguish between different languages and regional dialects, use a language
+    /// designator with a region designator and a script designator separated by
+    /// hyphens. To specify the English language as it's used in the United Kingdom,
+    /// use en-GB, where GB is the region designator. To represent Mandarin Chinese,
     /// spoken in Taiwan, and written in Traditional Chinese script, use zh-Hant-TW.
     ///
-    /// To specify a script, combine a language designator with a script designator separated by a hyphen,
-    /// as in az-Arab for Azerbaijani in the Arabic script.
+    /// To specify a script, combine a language designator with a script designator
+    /// separated by a hyphen, as in az-Arab for Azerbaijani in the Arabic script.
     ///
     /// ## Availability
     /// * iOS 2.0+
@@ -344,7 +341,7 @@ pub struct Localization {
     /// ## Framework
     /// Core Foundation
     #[serde(
-        rename(serialize = "CFBundleDevelopmentRegion"),
+        rename = "CFBundleDevelopmentRegion",
         skip_serializing_if = "Option::is_none"
     )]
     pub bundle_development_region: Option<String>,
@@ -359,12 +356,13 @@ pub struct Localization {
     /// ## Framework
     /// Core Foundation
     #[serde(
-        rename(serialize = "CFBundleLocalizations"),
+        rename = "CFBundleLocalizations",
         skip_serializing_if = "Option::is_none",
         serialize_with = "serialize_vec_enum_option"
     )]
     pub bundle_localizations: Option<Vec<BundleLocalizations>>,
-    /// A Boolean value that indicates whether the bundle supports the retrieval of localized strings from frameworks.
+    /// A Boolean value that indicates whether the bundle supports the retrieval of
+    /// localized strings from frameworks.
     ///
     /// ## Availability
     /// * iOS 2.0+
@@ -375,18 +373,21 @@ pub struct Localization {
     /// ## Framework
     /// Core Foundation
     #[serde(
-        rename(serialize = "CFBundleAllowMixedLocalizations"),
+        rename = "CFBundleAllowMixedLocalizations",
         skip_serializing_if = "Option::is_none"
     )]
     pub bundle_allow_mixed_localizations: Option<bool>,
-    /// A Boolean value that enables the Caps Lock key to switch between Latin and non-Latin input sources.
+    /// A Boolean value that enables the Caps Lock key to switch between Latin and
+    /// non-Latin input sources.
     ///
-    /// Latin input sources, such as ABC, U.S., and Vietnamese, output characters in Latin script.
-    /// Non-Latin input sources, such as Bulgarian (Cyrillic script), Hindi (Devanagari script), and Urdu (Arabic script),
-    /// output characters in scripts other than Latin.
+    /// Latin input sources, such as ABC, U.S., and Vietnamese, output characters in Latin
+    /// script. Non-Latin input sources, such as Bulgarian (Cyrillic script), Hindi
+    /// (Devanagari script), and Urdu (Arabic script), output characters in scripts
+    /// other than Latin.
     ///
-    /// After implementing the key, users can enable or disable this functionality by modifying
-    /// the “Use Caps Lock to switch to and from” preference, which can be found in System Preferences > Keyboard > Input Sources.
+    /// After implementing the key, users can enable or disable this functionality by
+    /// modifying the “Use Caps Lock to switch to and from” preference, which can be
+    /// found in System Preferences > Keyboard > Input Sources.
     ///
     /// ## Availability
     /// * macOS 10.15+
@@ -394,13 +395,13 @@ pub struct Localization {
     /// ## Framework
     /// * AppKit
     #[serde(
-        rename(serialize = "TICapsLockLanguageSwitchCapable"),
+        rename = "TICapsLockLanguageSwitchCapable",
         skip_serializing_if = "Option::is_none"
     )]
     pub caps_lock_language_switch_capable: Option<bool>,
 }
 
-/// Help.
+/// Help
 #[derive(Deserialize, Serialize, Debug, Clone, PartialEq, Default)]
 pub struct Help {
     /// The name of the bundle’s HTML help file.
@@ -410,10 +411,7 @@ pub struct Help {
     ///
     /// ## Framework
     /// * Core Foundation
-    #[serde(
-        rename(serialize = "CFAppleHelpAnchor"),
-        skip_serializing_if = "Option::is_none"
-    )]
+    #[serde(rename = "CFAppleHelpAnchor", skip_serializing_if = "Option::is_none")]
     pub apple_help_anchor: Option<String>,
     /// The name of the help file that will be opened in Help Viewer.
     ///
@@ -423,7 +421,7 @@ pub struct Help {
     /// ## Framework
     /// * Core Foundation
     #[serde(
-        rename(serialize = "CFBundleHelpBookName"),
+        rename = "CFBundleHelpBookName",
         skip_serializing_if = "Option::is_none"
     )]
     pub bundle_help_book_name: Option<String>,
@@ -435,98 +433,98 @@ pub struct Help {
     /// ## Framework
     /// * Core Foundation
     #[serde(
-        rename(serialize = "CFBundleHelpBookFolder"),
+        rename = "CFBundleHelpBookFolder",
         skip_serializing_if = "Option::is_none"
     )]
     pub bundle_help_book_folder: Option<String>,
 }
 
+/// App Category Type
 #[derive(Deserialize, Serialize, Debug, Clone, PartialEq)]
-#[serde(rename_all(deserialize = "kebab-case"))]
 pub enum AppCategoryType {
-    #[serde(rename(serialize = "public.app-category.business"))]
+    #[serde(rename = "public.app-category.business")]
     Business,
-    #[serde(rename(serialize = "public.app-category.developer-tools"))]
+    #[serde(rename = "public.app-category.developer-tools")]
     DeveloperTools,
-    #[serde(rename(serialize = "public.app-category.education"))]
+    #[serde(rename = "public.app-category.education")]
     Education,
-    #[serde(rename(serialize = "public.app-category.entertainment"))]
+    #[serde(rename = "public.app-category.entertainment")]
     Entertainment,
-    #[serde(rename(serialize = "public.app-category.finance"))]
+    #[serde(rename = "public.app-category.finance")]
     Finance,
-    #[serde(rename(serialize = "public.app-category.games"))]
+    #[serde(rename = "public.app-category.games")]
     Games,
-    #[serde(rename(serialize = "public.app-category.action-games"))]
+    #[serde(rename = "public.app-category.action-games")]
     ActionGames,
-    #[serde(rename(serialize = "public.app-category.adventure-games"))]
+    #[serde(rename = "public.app-category.adventure-games")]
     AdventureGames,
-    #[serde(rename(serialize = "public.app-category.arcade-games"))]
+    #[serde(rename = "public.app-category.arcade-games")]
     ArcadeGames,
-    #[serde(rename(serialize = "public.app-category.board-games"))]
+    #[serde(rename = "public.app-category.board-games")]
     BoardGames,
-    #[serde(rename(serialize = "public.app-category.card-games"))]
+    #[serde(rename = "public.app-category.card-games")]
     CardGames,
-    #[serde(rename(serialize = "public.app-category.casino-games"))]
+    #[serde(rename = "public.app-category.casino-games")]
     CasinoGames,
-    #[serde(rename(serialize = "public.app-category.dice-games"))]
+    #[serde(rename = "public.app-category.dice-games")]
     DiceGames,
-    #[serde(rename(serialize = "public.app-category.educational-games"))]
+    #[serde(rename = "public.app-category.educational-games")]
     EducationalGames,
-    #[serde(rename(serialize = "public.app-category.family-games"))]
+    #[serde(rename = "public.app-category.family-games")]
     FamilyGames,
-    #[serde(rename(serialize = "public.app-category.kids-games"))]
+    #[serde(rename = "public.app-category.kids-games")]
     KidsGames,
-    #[serde(rename(serialize = "public.app-category.music-games"))]
+    #[serde(rename = "public.app-category.music-games")]
     MusicGames,
-    #[serde(rename(serialize = "public.app-category.puzzle-games"))]
+    #[serde(rename = "public.app-category.puzzle-games")]
     PuzzleGames,
-    #[serde(rename(serialize = "public.app-category.racing-games"))]
+    #[serde(rename = "public.app-category.racing-games")]
     RacingGames,
-    #[serde(rename(serialize = "public.app-category.role-playing-games"))]
+    #[serde(rename = "public.app-category.role-playing-games")]
     RolePlayingGames,
-    #[serde(rename(serialize = "public.app-category.simulation-games"))]
+    #[serde(rename = "public.app-category.simulation-games")]
     SimulationGames,
-    #[serde(rename(serialize = "public.app-category.sports-games"))]
+    #[serde(rename = "public.app-category.sports-games")]
     SportsGames,
-    #[serde(rename(serialize = "public.app-category.strategy-games"))]
+    #[serde(rename = "public.app-category.strategy-games")]
     StrategyGames,
-    #[serde(rename(serialize = "public.app-category.trivia-games"))]
+    #[serde(rename = "public.app-category.trivia-games")]
     TriviaGames,
-    #[serde(rename(serialize = "public.app-category.word-games"))]
+    #[serde(rename = "public.app-category.word-games")]
     WordGames,
-    #[serde(rename(serialize = "public.app-category.graphics-design"))]
+    #[serde(rename = "public.app-category.graphics-design")]
     GraphicsDesign,
-    #[serde(rename(serialize = "public.app-category.healthcare-fitness"))]
+    #[serde(rename = "public.app-category.healthcare-fitness")]
     HealthcareFitness,
-    #[serde(rename(serialize = "public.app-category.lifestyle"))]
+    #[serde(rename = "public.app-category.lifestyle")]
     Lifestyle,
-    #[serde(rename(serialize = "public.app-category.medical"))]
+    #[serde(rename = "public.app-category.medical")]
     Medical,
-    #[serde(rename(serialize = "public.app-category.music"))]
+    #[serde(rename = "public.app-category.music")]
     Music,
-    #[serde(rename(serialize = "public.app-category.news"))]
+    #[serde(rename = "public.app-category.news")]
     News,
-    #[serde(rename(serialize = "public.app-category.photography"))]
+    #[serde(rename = "public.app-category.photography")]
     Photography,
-    #[serde(rename(serialize = "public.app-category.productivity"))]
+    #[serde(rename = "public.app-category.productivity")]
     Productivity,
-    #[serde(rename(serialize = "public.app-category.reference"))]
+    #[serde(rename = "public.app-category.reference")]
     Reference,
-    #[serde(rename(serialize = "public.app-category.social-networking"))]
+    #[serde(rename = "public.app-category.social-networking")]
     SocialNetworking,
-    #[serde(rename(serialize = "public.app-category.sports"))]
+    #[serde(rename = "public.app-category.sports")]
     Sports,
-    #[serde(rename(serialize = "public.app-category.travel"))]
+    #[serde(rename = "public.app-category.travel")]
     Travel,
-    #[serde(rename(serialize = "public.app-category.utilities"))]
+    #[serde(rename = "public.app-category.utilities")]
     Utilities,
-    #[serde(rename(serialize = "public.app-category.video"))]
+    #[serde(rename = "public.app-category.video")]
     Video,
-    #[serde(rename(serialize = "public.app-category.weather"))]
+    #[serde(rename = "public.app-category.weather")]
     Weather,
 }
 
-/// Operating System Version.
+/// Operating System Version
 #[derive(Deserialize, Serialize, Debug, Clone, PartialEq)]
 pub struct MinimumSystemVersionByArchitecture {
     pub i386: String,
@@ -545,25 +543,26 @@ impl Default for MinimumSystemVersionByArchitecture {
         }
     }
 }
+
+/// Bundle Localizations
 #[derive(Deserialize, Serialize, Debug, Clone, PartialEq)]
-#[serde(rename_all(deserialize = "kebab-case"))]
 pub enum BundleLocalizations {
-    #[serde(rename(serialize = "zh"))]
+    #[serde(rename = "zh")]
     Zh,
-    #[serde(rename(serialize = "zh_CN"))]
-    ZhCN,
-    #[serde(rename(serialize = "zh_TW"))]
-    ZhTW,
-    #[serde(rename(serialize = "en"))]
+    #[serde(rename = "zh_CN")]
+    ZhCn,
+    #[serde(rename = "zh_TW")]
+    ZhTw,
+    #[serde(rename = "en")]
     En,
-    #[serde(rename(serialize = "fr"))]
+    #[serde(rename = "fr")]
     Fr,
-    #[serde(rename(serialize = "de"))]
+    #[serde(rename = "de")]
     De,
-    #[serde(rename(serialize = "it"))]
+    #[serde(rename = "it")]
     It,
-    #[serde(rename(serialize = "ja"))]
+    #[serde(rename = "ja")]
     Ja,
-    #[serde(rename(serialize = "ko"))]
+    #[serde(rename = "ko")]
     Ko,
 }
